==> kotlin-compiler-0.10.709-sources.jar: org/jetbrains/kotlin/cfg/pseudocode/instructions/special/SubroutineEnterInstruction.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.cfg.pseudocode.instructions.special

import org.jetbrains.kotlin.psi.JetElement
import org.jetbrains.kotlin.cfg.pseudocode.instructions.LexicalScope
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionWithNext
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionVisitor
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionVisitorWithResult
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionImpl

public class SubroutineEnterInstruction(
        public val subroutine: JetElement,
        lexicalScope: LexicalScope
) : InstructionWithNext(subroutine, lexicalScope) {
    override fun accept(visitor: InstructionVisitor) {
        visitor.visitSubroutineEnter(this)
    }

    override fun <R> accept(visitor: InstructionVisitorWithResult<R>): R {
        return visitor.visitSubroutineEnter(this)
    }

    override fun toString(): String = "<START>"

    override fun createCopy(): InstructionImpl =
            SubroutineEnterInstruction(subroutine, lexicalScope)
}

==> kotlin-compiler-1.0.7-sources.jar: org/jetbrains/kotlin/cfg/pseudocode/instructions/special/SubroutineEnterInstruction.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.cfg.pseudocode.instructions.special

import org.jetbrains.kotlin.psi.KtElement
import org.jetbrains.kotlin.cfg.pseudocode.instructions.BlockScope
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionWithNext
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionVisitor
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionVisitorWithResult
import org.jetbrains.kotlin.cfg.pseudocode.instructions.InstructionImpl

class SubroutineEnterInstruction(
        val subroutine: KtElement,
        blockScope: BlockScope
) : InstructionWithNext(subroutine, blockScope) {
    override fun accept(visitor: InstructionVisitor) {
        visitor.visitSubroutineEnter(this)
    }

    override fun <R> accept(visitor: InstructionVisitorWithResult<R>): R {
        return visitor.visitSubroutineEnter(this)
    }

    override fun toString(): String = "<START>"

    override fun createCopy(): InstructionImpl =
            SubroutineEnterInstruction(subroutine, blockScope)
}
